import 'package:dio/dio.dart';

typedef void _OnLogCallback(dynamic log);

class HttpLogInterceptor extends Interceptor {
  _OnLogCallback log;

  HttpLogInterceptor(this.log);

  @override
  void onRequest(
    RequestOptions options,
    RequestInterceptorHandler handler,
  ) {
    log('============================================================');
    log("[${options.method}] ${options.uri.toString()}");
    log(options.headers);
    log(options.data);
    log('------------------------------------------------------------');

    return handler.next(options);
  }

  @override
  void onResponse(Response response, ResponseInterceptorHandler handler) {
    log('HTTP StatusCode: ${response.statusCode}');
    log(response.headers);
    log(response.data);
    log('------------------------------------------------------------');

    return handler.next(response);
  }

  @override
  void onError(DioError err, ErrorInterceptorHandler handler) {
    log('HTTP StatusCode: ${err.response?.statusCode}');
    log(err.toString());
    log(err.response?.headers.toString());
    log(err.response?.data);
    log('------------------------------------------------------------');

    return handler.next(err);
  }
}
